# History

## 0.7.0 (2022-05-11)

* Add `LmdbDatabaseClient` as the `minos.common.DatabaseClient` implementation for `lmdb`.
* Add `LmdbDatabaseOperation` and `LmdbDatabaseOperationType` classes to define `minos.common.DatabaseOperation`s compatible with the `lmdb` database. 
* Add `LmdbSagaExecutionDatabaseOperationFactory` as the `minos.saga.SagaExecutionDatabaseOperationFactory` implementation for `lmdb`. 
